.. Cloud Inquisitor documentation master file, created by
   sphinx-quickstart on Mon Apr 17 17:14:10 2017.
   You can adapt this file completely to your liking, but it should at least
   contain the root `toctree` directive.

Cloud Inquisitor
================

.. toctree::
    :maxdepth: 3

    api_documentation


.. include:: authors.rst

Indices and tables
==================

* :ref:`genindex`
* :ref:`modindex`
* :ref:`search`
